@@ -1129,7 +1129,7 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
                            R.version$platform,
                            utils::packageVersion("Rcpp"),
                            sep = "-"))
-    if (!dir.exists(dir))
+    if (!utils::file_test("-d", dir))
         dir.create(dir, recursive = TRUE)
 
     dir
@@ -1154,7 +1154,7 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
     as.character(token)
 }
 
-.extraRoutineRegistrations <- function(routines) {
+.extraRoutineRegistrations <- function(targetFile, routines) {
 
     declarations = character()
     call_entries = character()
@@ -1163,11 +1163,14 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
     # to automatically discover additional native routines that require registration
     if (getRversion() >= "3.4") {
 
+        # determine the package directory
+        pkgdir <- dirname(dirname(targetFile))
+
         # get the generated code from R
         con <- textConnection(object = NULL, open = "w")
         on.exit(close(con), add = TRUE)
         tools::package_native_routine_registration_skeleton(
-            dir = ".",
+            dir = pkgdir,
             con = con,
             character_only = FALSE
         )
