@@ -39,7 +39,11 @@ public:
         start(parent.begin() + static_cast<R_xlen_t>(i) * n ),
         const_start(const_cast<const MATRIX&>(parent).begin() + static_cast<R_xlen_t>(i) * n)
     {
-        if( i < 0 || i >= parent.ncol() ) throw index_out_of_bounds() ;
+        if( i < 0 || i >= parent.ncol() ) {
+            const char* fmt = "Column index is out of bounds: "
+                              "[index=%i; column extent=%i].";
+            throw index_out_of_bounds(fmt, i, parent.ncol()) ;
+        }
     }
 
     MatrixColumn( const MATRIX& parent, int i ) :
@@ -47,7 +51,11 @@ public:
         start( const_cast<MATRIX&>(parent).begin() + static_cast<R_xlen_t>(i) * n ),
         const_start(parent.begin() + static_cast<R_xlen_t>(i) * n)
     {
-        if( i < 0 || i >= parent.ncol() ) throw index_out_of_bounds() ;
+        if( i < 0 || i >= parent.ncol() ) {
+            const char* fmt = "Column index is out of bounds: "
+                              "[index=%i; column extent=%i].";
+            throw index_out_of_bounds(fmt, i, parent.ncol()) ;
+        }
     }
 
     MatrixColumn( const MatrixColumn& other ) :
@@ -115,13 +123,17 @@ public:
         n(parent.nrow()),
         const_start(parent.begin() + i *n)
     {
-        if( i < 0 || i >= parent.ncol() ) throw index_out_of_bounds() ;
+        if( i < 0 || i >= parent.ncol() ) {
+            const char* fmt = "Column index is out of bounds: "
+                              "[index=%i; column extent=%i].";
+            throw index_out_of_bounds(fmt, i, parent.ncol()) ;
+        }
     }
 
     ConstMatrixColumn( const ConstMatrixColumn& other ) :
         n(other.n),
         const_start(other.const_start) {}
-        
+
     inline const_Proxy operator[]( int i ) const {
         return const_start[i] ;
     }
